# -*- coding: utf-8 -*-


__name__ = "bay_lang"
__version__ = "0.0.1"
__description__ = "Bay Lang"
__license__ = "Apache License Version 2.0"
__author__ = "Ildar Bikmamatov"
__email__ = "support@bayrell.org"
__copyright__ = "Copyright 2016-2023"
__url__ = "https://bayrell.org/ru/docs/bay-lang/"
